--- title: "wallaroo.ModelConversion" type: docs linkTitle: "wallaroo.ModelConversion" ---
class ModelConversionInputType(enum.Enum):

An enumeration.

Float16 = <ModelConversionInputType.Float16: 'float16'>
Float32 = <ModelConversionInputType.Float32: 'float32'>
Float64 = <ModelConversionInputType.Float64: 'float64'>
Int16 = <ModelConversionInputType.Int16: 'int16'>
Int32 = <ModelConversionInputType.Int32: 'int32'>
Int64 = <ModelConversionInputType.Int64: 'int64'>
UInt8 = <ModelConversionInputType.UInt8: 'uint8'>
UInt16 = <ModelConversionInputType.UInt16: 'uint16'>
UInt32 = <ModelConversionInputType.UInt32: 'uint32'>
UInt64 = <ModelConversionInputType.UInt64: 'uint64'>
Boolean = <ModelConversionInputType.Boolean: 'bool'>
Double = <ModelConversionInputType.Double: 'double'>

##### Inherited Members

enum.Enum
  name
  value

class ConvertKerasArguments(typing.NamedTuple):

ConvertKerasArguments(name, comment, input_type, dimensions)

ConvertKerasArguments( name: str, comment: Optional[str], input_type: wallaroo.ModelConversion.ModelConversionInputType, dimensions: List[Union[NoneType, int, float]])

Create new instance of ConvertKerasArguments(name, comment, input_type, dimensions)

name: str

Alias for field number 0

comment: Optional[str]

Alias for field number 1

input_type: wallaroo.ModelConversion.ModelConversionInputType

Alias for field number 2

dimensions: List[Union[NoneType, int, float]]

Alias for field number 3

def to_dict(self) -> Dict[str, Any]:

##### Inherited Members

builtins.tuple
  index
  count

class ConvertSKLearnArguments(typing.NamedTuple):

ConvertSKLearnArguments(name, number_of_columns, input_type, comment)

ConvertSKLearnArguments( name: str, number_of_columns: int, input_type: wallaroo.ModelConversion.ModelConversionInputType, comment: Optional[str])

Create new instance of ConvertSKLearnArguments(name, number_of_columns, input_type, comment)

name: str

Alias for field number 0

number_of_columns: int

Alias for field number 1

input_type: wallaroo.ModelConversion.ModelConversionInputType

Alias for field number 2

comment: Optional[str]

Alias for field number 3

def to_dict(self) -> Dict[str, Any]:

##### Inherited Members

builtins.tuple
  index
  count

class ConvertXGBoostArgs(typing.NamedTuple):

ConvertXGBoostArgs(name, number_of_columns, input_type, comment)

ConvertXGBoostArgs( name: str, number_of_columns: int, input_type: wallaroo.ModelConversion.ModelConversionInputType, comment: Optional[str])

Create new instance of ConvertXGBoostArgs(name, number_of_columns, input_type, comment)

name: str

Alias for field number 0

number_of_columns: int

Alias for field number 1

input_type: wallaroo.ModelConversion.ModelConversionInputType

Alias for field number 2

comment: Optional[str]

Alias for field number 3

def to_dict(self) -> Dict[str, Any]:

##### Inherited Members

builtins.tuple
  index
  count

class ModelConversionSource(enum.Enum):

An enumeration.

KERAS = <ModelConversionSource.KERAS: 'keras'>
XGBOOST = <ModelConversionSource.XGBOOST: 'xgboost'>
SKLEARN = <ModelConversionSource.SKLEARN: 'sklearn'>

##### Inherited Members

enum.Enum
  name
  value

class ModelConversionGenericException(builtins.Exception):

Common base class for all non-exit exceptions.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class ModelConversionFailure(builtins.Exception):

Common base class for all non-exit exceptions.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class ModelConversionUnsupportedType(builtins.Exception):

Common base class for all non-exit exceptions.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args

class ModelConversionSourceFileNotPresent(builtins.Exception):

Common base class for all non-exit exceptions.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback
  args